# Default Resolver

::: dqf.build_default_resolver

## Pipeline factories

These are exported individually so you can mix them with custom rules.

::: dqf.defaults.suites.identifier_pipeline

::: dqf.defaults.suites.target_binary_pipeline

::: dqf.defaults.suites.target_binary_pipeline_no_time

::: dqf.defaults.suites.target_categorical_pipeline

::: dqf.defaults.suites.target_categorical_pipeline_no_time

::: dqf.defaults.suites.target_continuous_pipeline

::: dqf.defaults.suites.target_continuous_pipeline_no_time

::: dqf.defaults.suites.numeric_continuous_pipeline

::: dqf.defaults.suites.numeric_continuous_pipeline_no_time

::: dqf.defaults.suites.numeric_discrete_pipeline

::: dqf.defaults.suites.categorical_pipeline

::: dqf.defaults.suites.boolean_pipeline

::: dqf.defaults.suites.catch_all_pipeline
